@@ -5,8 +5,8 @@ from typing import Union
 
 from faker import Faker
 
-from lokii.config import LokiConfig
-from lokii.table.table import Table
+from .config import LokiConfig
+from table.table import Table
 
 
 def get_table_path(out_folder: str, name: str):
